==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGridFormGroupCreatedEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGridFormGroupCreatedEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridFormGroupCreatedEventArgsDetailDescription, _super);
    function WebGridFormGroupCreatedEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebGridFormGroupCreatedEventArgsDetailDescription.prototype.get_type = function () {
        return "WebGridFormGroupCreatedEventArgsDetail";
    };
    Object.defineProperty(WebGridFormGroupCreatedEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGridFormGroupCreatedEventArgsDetailDescription.prototype, "owner", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Owner");
        },
        enumerable: true,
        configurable: true
    });
    WebGridFormGroupCreatedEventArgsDetailDescription.$t = markType(WebGridFormGroupCreatedEventArgsDetailDescription, 'WebGridFormGroupCreatedEventArgsDetailDescription', Description.$);
    WebGridFormGroupCreatedEventArgsDetailDescription.__marshalByValue = true;
    WebGridFormGroupCreatedEventArgsDetailDescription.__marshalByValueAlias = "GridFormGroupCreatedEventArgsDetail";
    return WebGridFormGroupCreatedEventArgsDetailDescription;
}(Description));
export { WebGridFormGroupCreatedEventArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebGridFormGroupCreatedEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGridFormGroupCreatedEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridFormGroupCreatedEventArgsDetailDescription, _super);
    function WebGridFormGroupCreatedEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        return _this;
    }
    WebGridFormGroupCreatedEventArgsDetailDescription.prototype.get_type = function () {
        return "WebGridFormGroupCreatedEventArgsDetail";
    };
    Object.defineProperty(WebGridFormGroupCreatedEventArgsDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGridFormGroupCreatedEventArgsDetailDescription.prototype, "owner", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("Owner");
        },
        enumerable: false,
        configurable: true
    });
    WebGridFormGroupCreatedEventArgsDetailDescription.$t = markType(WebGridFormGroupCreatedEventArgsDetailDescription, 'WebGridFormGroupCreatedEventArgsDetailDescription', Description.$);
    WebGridFormGroupCreatedEventArgsDetailDescription.__marshalByValue = true;
    WebGridFormGroupCreatedEventArgsDetailDescription.__marshalByValueAlias = "GridFormGroupCreatedEventArgsDetail";
    return WebGridFormGroupCreatedEventArgsDetailDescription;
}(Description));
export { WebGridFormGroupCreatedEventArgsDetailDescription };
